AuthStore class

ALLOWS USER TO IMPLEMENT CUSTOM AUTH STORAGE MECHANISMS

Constructors

AuthStore({required dynamic setToken(String), required Future<String?> getToken()})

Properties

getToken ↔ Future<String?> Function()
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setToken ↔ dynamic Function(String)
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited