AggregateOperation enum

Aggregate operations for document queries

Inheritance
Available extensions

Values

sum → const AggregateOperation
avg → const AggregateOperation
min → const AggregateOperation
max → const AggregateOperation

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Convert enum to string for API requests
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AggregateOperation>
A constant List of the values in this enum, in order of their declaration.