FunctionResponse<T> class

Response from a cloud function execution

Constructors

FunctionResponse({required T result, required bool success, String? error, required double executionTime, required String output})
FunctionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

error → String?
Error message if the function failed, null otherwise
final
executionTime → double
Time taken to execute the function in milliseconds
final
hashCode → int
The hash code for this object.
no setterinherited
output → String
Console output from the function execution
final
result → T
The result returned by the function
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → bool
Whether the function executed successfully
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited