AppUser class

Constructors

AppUser({required String id, required String email, required Map<String, dynamic> data, List<String>? roles, required DateTime createdAt, required DateTime updatedAt})
AppUser.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt → DateTime
final
data → Map<String, dynamic>
final
email → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
roles → List<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited