BatchCreateResponse<T> class

Constructors

BatchCreateResponse({required int created, required List<Document<T>> documents})
BatchCreateResponse.fromJson(Map<String, dynamic> json)
factory

Properties

created int
final
documents List<Document<T>>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited