CocobaseConverters class
Registry for automatic model converters
Register your models so listDocuments
Example:
CocobaseConverters.register<Book>(Book.fromJson);
// Now this works without the converter parameter:
final books = await db.listDocuments<Book>("books");
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited