CocobaseAuthBuilder class

Rebuilds when the user's auth state changes.

The simplest way to gate UI on authentication:

CocobaseAuthBuilder(
  db: db,
  authenticated: (context, user) => HomePage(user: user),
  unauthenticated: (context) => LoginPage(),
  loading: SplashScreen(),
)
Inheritance

Constructors

CocobaseAuthBuilder({Key? key, required Cocobase db, required Widget authenticated(BuildContext context, AppUser? user), required Widget unauthenticated(BuildContext context), Widget? loading})
const

Properties

authenticated → Widget Function(BuildContext context, AppUser? user)
final
db → Cocobase
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loading → Widget?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unauthenticated → Widget Function(BuildContext context)
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<CocobaseAuthBuilder>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited