CocobaseDocument<T> class

Fetches and displays a single document by ID.

CocobaseDocument<Post>(
  db: db,
  collection: 'posts',
  docId: widget.postId,
  converter: Post.fromJson,
  builder: (context, post) => PostDetail(post: post),
)
Inheritance

Constructors

CocobaseDocument({Key? key, required Cocobase db, required String collection, required String docId, required Widget builder(BuildContext context, Document<T> doc), T converter(Map<String, dynamic>)?, List<String>? populate, Widget? loading, Widget errorBuilder(BuildContext context, CocobaseError error)?})
const

Properties

builder → Widget Function(BuildContext context, Document<T> doc)
final
collection → String
final
converter → T Function(Map<String, dynamic>)?
final
db → Cocobase
final
docId → String
final
errorBuilder → Widget Function(BuildContext context, CocobaseError error)?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loading → Widget?
final
populate → List<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<CocobaseDocument<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited