CocobaseInfiniteList<T> class

A list that automatically loads the next page as the user scrolls to the bottom. No buttons needed.

CocobaseInfiniteList<Post>(
  db: db,
  collection: 'posts',
  pageSize: 20,
  converter: Post.fromJson,
  itemBuilder: (context, doc, index) => PostCard(post: doc),
  separatorBuilder: (context, index) => const Divider(),
)
Inheritance

Constructors

CocobaseInfiniteList({Key? key, required Cocobase db, required String collection, required Widget itemBuilder(BuildContext context, Document<T> doc, int index), QueryBuilder? queryBuilder, Map<String, dynamic>? filters, T converter(Map<String, dynamic>)?, Widget separatorBuilder(BuildContext context, int index)?, int pageSize = 20, Widget? loading, Widget? emptyState, Widget errorBuilder(BuildContext context, CocobaseError error)?, ScrollController? scrollController})
const

Properties

collection String
final
converter → T Function(Map<String, dynamic>)?
final
db Cocobase
final
emptyState Widget?
final
errorBuilder Widget Function(BuildContext context, CocobaseError error)?
final
filters Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
itemBuilder Widget Function(BuildContext context, Document<T> doc, int index)
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loading Widget?
final
pageSize int
final
queryBuilder QueryBuilder?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollController ScrollController?
final
separatorBuilder Widget Function(BuildContext context, int index)?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CocobaseInfiniteList<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited