PaginationMode enum

A paginated list that loads documents page by page.

Supports two modes:

  • Load more (default): appends to the list as the user scrolls
  • Numbered pages: replaces the list on page change
// Load more
CocobasePaginatedList<Post>(
  db: db,
  collection: 'posts',
  pageSize: 20,
  converter: Post.fromJson,
  itemBuilder: (context, doc) => PostCard(post: doc),
)

// Numbered pages
CocobasePaginatedList<Post>(
  db: db,
  collection: 'posts',
  mode: PaginationMode.numbered,
  converter: Post.fromJson,
  itemBuilder: (context, doc) => PostCard(post: doc),
)
Inheritance
Available extensions

Values

loadMore → const PaginationMode
numbered → const PaginationMode

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PaginationMode>
A constant List of the values in this enum, in order of their declaration.