AuthCallbacks class
Authentication callbacks container
Constructors
- AuthCallbacks({OnLoginCallback? onLogin, OnLogoutCallback? onLogout, OnRegisterCallback? onRegister, OnUserUpdateCallback? onUserUpdate, OnTokenChangeCallback? onTokenChange, OnAuthStateChangeCallback? onAuthStateChange})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onAuthStateChange → OnAuthStateChangeCallback?
-
final
- onLogin → OnLoginCallback?
-
final
- onLogout → OnLogoutCallback?
-
final
- onRegister → OnRegisterCallback?
-
final
- onTokenChange → OnTokenChangeCallback?
-
final
- onUserUpdate → OnUserUpdateCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
merge(
AuthCallbacks other) → AuthCallbacks - Merge with another AuthCallbacks object
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited