CocobaseError class

Implemented types
Implementers

Constructors

CocobaseError({required int statusCode, required String url, required String method, required dynamic detail, required String suggestion})
const

Properties

detail → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
method String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final
suggestion String
final
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited