AppUserList class
Response containing a list of users from auth collection
Constructors
-
AppUserList({required List<
AppUser> data, required int total, required int limit, required int offset, required bool hasMore}) -
AppUserList.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
data
→ List<
AppUser> -
Array of user objects
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMore → bool
-
Whether there are more users beyond this page
final
- limit → int
-
Limit used for this query
final
- offset → int
-
Offset used for this query
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- total → int
-
Total number of users matching the query
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited