Document<T> class

Constructors

Document({required String id, required Map<String, dynamic> collection, required T data, required DateTime createdAt, required DateTime updatedAt})
Document.fromJson(Map<String, dynamic> json)
factory

Properties

collection Map<String, dynamic>
final
createdAt DateTime
final
data → T
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited