ReconnectingWebSocket class

Reconnecting WebSocket implementation with automatic reconnection

Constructors

ReconnectingWebSocket(String url, Map<String, dynamic> authData)

Properties

authData Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final

Methods

close() → void
connect() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onMessage(void callback(MessageEvent)) → void
send(Map<String, dynamic> message) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited