CocobaseLiveQuery<T> class
Subscribes to a collection and rebuilds whenever data changes.
Uses Cocobase.onSnapshot under the hood — fires immediately with current data then again on every create/update/delete.
CocobaseLiveQuery<Message>(
db: db,
collection: 'messages',
queryBuilder: QueryBuilder().orderByDesc('created_at').limit(50),
converter: Message.fromJson,
builder: (context, messages) => MessageList(messages: messages),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CocobaseLiveQuery
Constructors
-
CocobaseLiveQuery({Key? key, required Cocobase db, required String collection, required Widget builder(BuildContext context, List<
Document< docs), QueryBuilder? queryBuilder, Map<T> >String, dynamic> ? filters, T converter(Map<String, dynamic> )?, Widget? loading, Widget errorBuilder(BuildContext context, CocobaseError error)?}) -
const
Properties
-
builder
→ Widget Function(BuildContext context, List<
Document< docs)T> > -
final
- collection → String
-
final
-
converter
→ T Function(Map<
String, dynamic> )? -
final
- db → Cocobase
-
final
- errorBuilder → Widget Function(BuildContext context, CocobaseError error)?
-
final
-
filters
→ Map<
String, dynamic> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- loading → Widget?
-
final
- queryBuilder → QueryBuilder?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CocobaseLiveQuery< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited